==> raqdevil-0.9.6.tar.gz: raqdevil-0.9.6/cce-handlers-1.0/handlers/base/apache/virtual_host.pl <==
#!/usr/bin/perl -I/usr/local/raqdevil/perl
# $Id: virtual_host.pl,v 1.10 2005/10/07 06:41:40 dodell Exp $
# Copyright 2000, 2001 Sun Microsystems, Inc., All rights reserved.
# handle the creation of configuration files for individual vhosts
#

use CCE;
use Sauce::Config;
use Sauce::Util;
use Base::Httpd qw(httpd_get_vhost_conf_file);
use Data::Dumper;
use FileHandle;

my $DEBUG = 2;

my $cce = new CCE;

$cce->connectfd();

my $vhost = $cce->event_object();
my $vsite;

# To implement updating SSL handlers in httpd.conf when SSL is activated or
# deactivated, we must allow this script to determine what kind of OID we have
# since this can be Vsite (the SSL namespace lives in Vsite.SSL) or the default
# VirtualHost namespace, which is what previously was always given to this
# script.
#
# To test which namespace we have, I first request the SSL sub-object. This
# does not exist in VirtualHost, so if we actually get something back, we know
# we have a Vsite event object.
#
# After this, we look up the VirtualHost object with the same name (site2, for
# instance) as the Vsite we have been given. If this isn't found, we have a
# big problem.

my ($success, $testobj) = $cce->get($cce->event_oid(), 'SSL');
if ($success) {
	$vsite = $vhost;
	($testoid) = $cce->find("VirtualHost", { "name" => $vhost->{name} } );
	($success, $vhost) = $cce->get($testoid);
	if (!$success) {
		$cce->bye('FAIL', 'Could not find VirtualHost with matching name as in Vsite namespace');
		exit(1);
	}
}

my $vhost_new = $cce->event_new();
my $vhost_old = $cce->event_old();

my $vsite;
my ($testoid) = $cce->find("Vsite", { "fqdn" => $vhost->{fqdn} } );
($success, $vsite) = $cce->get($testoid);
if (!$success) {
	$cce->bye('FAIL', 'Could not find Vsite with matching FQDN');
	exit (1);
}

# make sure the directory exists before trying to edit the file
if (!-d $Base::Httpd::vhost_dir)
{
    Sauce::Util::makedirectory($Base::Httpd::vhost_dir);
    Sauce::Util::chmodfile(0751, $Base::Httpd::vhost_dir);
}

if (!Sauce::Util::editfile(
        httpd_get_vhost_conf_file($vhost->{name}), 
        *edit_vhost, $vhost))
{
    $cce->bye('FAIL', '[[base-apache.cantEditVhost]]');
    exit(1);
}

Sauce::Util::chmodfile(0644, httpd_get_vhost_conf_file($vhost->{name}));

# create include file
my $include_file = httpd_get_vhost_conf_file($vhost->{name}) . '.include';
if (!-e $include_file) {
    my $fh = new FileHandle(">$include_file");
    if ($fh) {
	print $fh "# ${include_file}\n";
	print $fh "# user customizations can be added here.\n\n";
	$fh->close();
    }
    Sauce::Util::chmodfile(0644, $include_file);
}

$cce->bye('SUCCESS');
exit(0);


sub edit_vhost
{
    my ($in, $out, $vhost) = @_;

    my $user_root = $vhost->{documentRoot};
    $user_root =~ s#web$#users/\$1/web/\$3#;

    my $site_root = $vhost->{documentRoot};
    $site_root =~ s/\/web$//;

    my $include_file = httpd_get_vhost_conf_file($vhost->{name}) . '.include';

    ($vsoid) = $cce->find("Vsite", { "name" => $vhost->{name} });
    my ($success, $ssl) = $cce->get($vsoid, "SSL");
    my ($success, $vsite) = $cce->get($vsoid);

my $aliases =~ tr/\&/ /;

    my $vhost_conf =<<END;
# owned by VirtualHost
NameVirtualHost $vhost->{ipaddr}:80

# FrontPage needs the following four things to be here
# otherwise all the vhosts need to go in httpd.conf, which could
# get very large since there could be thousands of vhosts
ServerRoot /usr/local

<VirtualHost $vhost->{ipaddr}:80>
ServerName $vhost->{fqdn}
ServerAlias $aliases $vhost->{fqdn}
ServerAdmin $vhost->{serverAdmin}
DocumentRoot $vhost->{documentRoot}
CustomLog $vsite->{basedir}/logs/access_log combined
CustomLog /var/log/httpd-access.log combined_vhost
ErrorLog $vsite->{basedir}/logs/error_log
ErrorDocument 401 /error/401-authorization.html
ErrorDocument 403 /error/403-forbidden.html
ErrorDocument 404 /error/404-file-not-found.html
ErrorDocument 500 /error/500-internal-server-error.html
RewriteEngine on
RewriteCond %{HTTP_HOST}                !^$vhost->{ipaddr}(:80)?\$
RewriteCond %{HTTP_HOST}                !^$vhost->{fqdn}(:80)?\$ [NC]
RewriteRule ^/(.*)                      http://$vhost->{fqdn}/\$1 [L,R]
RewriteOptions inherit
AliasMatch ^/~([^/]+)(/(.*))?           $user_root
Include $include_file
</VirtualHost>
END

    if ($ssl->{enabled}) {
	if (-f "$vsite->{basedir}/certs/ca-certs")
	{
		$cafile = "SSLCACertificateFile	$vsite->{basedir}/certs/ca-certs";
	}
	if (-f "$vsite->{basedir}/certs/certificate" &&
	    -f "$vstie->{basedir}/certs/key") {
		$vhost_conf .=<<END;
<VirtualHost $vhost->{ipaddr}:443>
SSLengine on
$cafile
SSLCertificateFile 	$vsite->{basedir}/certs/certificate
SSLCertificateKeyFile	$vsite->{basedir}/certs/key
ServerName $vhost->{fqdn}
ServerAlias $vsite->{webAliases}
ServerAdmin $vhost->{serverAdmin}
DocumentRoot $vhost->{documentRoot}
ErrorDocument 401 /error/401-authorization.html
ErrorDocument 403 /error/403-forbidden.html
ErrorDocument 404 /error/404-file-not-found.html
ErrorDocument 500 /error/500-internal-server-error.html
</VirtualHost>
END
	} else {
		$cce->bye('FAIL', "Can't add SSL configuration to a site with no certificate!");
	}
    }

    # append line marking the end of the section specifically owned by the VirtualHost
    my $end_mark = "# end of VirtualHost owned section\n";
    $vhost_conf .= $end_mark;

    my $conf_printed = 0;

    while (<$in>)
    {
    	if (!$conf_printed && /^$end_mark$/)
    	{
    		print $out $vhost_conf;
    		$conf_printed = 1;
    	}
    	elsif ($conf_printed)
    	{
    		# print out information entered by other objects
    		print $out $_;
    	}
    }

    if (!$conf_printed)
    {
    	print $out $vhost_conf;
    }

    return 1;
}
# Copyright (c) 2003 Sun Microsystems, Inc. All  Rights Reserved.
# 
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions are met:
# 
# -Redistribution of source code must retain the above copyright notice, 
# this list of conditions and the following disclaimer.
# 
# -Redistribution in binary form must reproduce the above copyright notice, 
# this list of conditions and the following disclaimer in the documentation  
# and/or other materials provided with the distribution.
# 
# Neither the name of Sun Microsystems, Inc. or the names of contributors may 
# be used to endorse or promote products derived from this software without 
# specific prior written permission.
# 
# This software is provided "AS IS," without a warranty of any kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY EXCLUDED. SUN MICROSYSTEMS, INC. ("SUN") AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
# 
# You acknowledge that  this software is not designed or intended for use in the design, construction, operation or maintenance of any nuclear facility.

==> raqdevil-1.0.tar.gz: raqdevil-1.0/cce-handlers-1.0/handlers/base/apache/virtual_host.pl <==
#!/usr/bin/perl -I/usr/local/raqdevil/perl
# $Id: virtual_host.pl,v 1.13 2005/12/13 20:09:28 dodell Exp $
# Copyright 2000, 2001 Sun Microsystems, Inc., All rights reserved.
# handle the creation of configuration files for individual vhosts
#

use CCE;
use Sauce::Config;
use Sauce::Util;
use Base::Httpd qw(httpd_get_vhost_conf_file);
use Data::Dumper;
use FileHandle;

my $DEBUG = 0;

my $cce = new CCE;

$cce->connectfd();

my $vhost = $cce->event_object();
my $vsite;

# To implement updating SSL handlers in httpd.conf when SSL is activated or
# deactivated, we must allow this script to determine what kind of OID we have
# since this can be Vsite (the SSL namespace lives in Vsite.SSL) or the default
# VirtualHost namespace, which is what previously was always given to this
# script.
#
# To test which namespace we have, I first request the SSL sub-object. This
# does not exist in VirtualHost, so if we actually get something back, we know
# we have a Vsite event object.
#
# After this, we look up the VirtualHost object with the same name (site2, for
# instance) as the Vsite we have been given. If this isn't found, we have a
# big problem.

my ($success, $testobj) = $cce->get($cce->event_oid(), 'SSL');
if ($success) {
	$vsite = $vhost;
	($testoid) = $cce->find("VirtualHost", { "name" => $vhost->{name} } );
	($success, $vhost) = $cce->get($testoid);
	if (!$success) {
		$cce->bye('FAIL', 'Could not find VirtualHost with matching name as in Vsite namespace');
		exit(1);
	}
}

my $vhost_new = $cce->event_new();
my $vhost_old = $cce->event_old();

my $vsite;
my ($testoid) = $cce->find("Vsite", { "fqdn" => $vhost->{fqdn} } );
($success, $vsite) = $cce->get($testoid);
if (!$success) {
	$cce->bye('FAIL', 'Could not find Vsite with matching FQDN');
	exit (1);
}

# make sure the directory exists before trying to edit the file
if (!-d $Base::Httpd::vhost_dir)
{
    Sauce::Util::makedirectory($Base::Httpd::vhost_dir);
    Sauce::Util::chmodfile(0751, $Base::Httpd::vhost_dir);
}

if (!Sauce::Util::editfile(
        httpd_get_vhost_conf_file($vhost->{name}), 
        *edit_vhost, $vhost))
{
    $cce->bye('FAIL', '[[base-apache.cantEditVhost]]');
    exit(1);
}

Sauce::Util::chmodfile(0644, httpd_get_vhost_conf_file($vhost->{name}));

# create include file
my $include_file = httpd_get_vhost_conf_file($vhost->{name}) . '.include';
if (!-e $include_file) {
    my $fh = new FileHandle(">$include_file");
    if ($fh) {
	print $fh "# ${include_file}\n";
	print $fh "# user customizations can be added here.\n\n";
	$fh->close();
    }
    Sauce::Util::chmodfile(0644, $include_file);
}

$cce->bye('SUCCESS');
exit(0);


sub edit_vhost
{
    my ($in, $out, $vhost) = @_;

    my $user_root = $vhost->{documentRoot};
    $user_root =~ s#web$#users/\$1/web/\$3#;

    my $site_root = $vhost->{documentRoot};
    $site_root =~ s/\/web$//;

    my $include_file = httpd_get_vhost_conf_file($vhost->{name}) . '.include';

    ($vsoid) = $cce->find("Vsite", { "name" => $vhost->{name} });
    my ($success, $ssl) = $cce->get($vsoid, "SSL");
    my ($success, $vsite) = $cce->get($vsoid);

my $aliases =~ tr/\&/ /;

    my $vhost_conf =<<END;
# owned by VirtualHost
NameVirtualHost $vhost->{ipaddr}:80

# FrontPage needs the following four things to be here
# otherwise all the vhosts need to go in httpd.conf, which could
# get very large since there could be thousands of vhosts
ServerRoot /usr/local

<VirtualHost $vhost->{ipaddr}:80>
ServerName $vhost->{fqdn}
ServerAlias $aliases $vhost->{fqdn}
ServerAdmin $vhost->{serverAdmin}
DocumentRoot $vhost->{documentRoot}
CustomLog $vsite->{basedir}/logs/access_log combined
CustomLog /var/log/httpd-access.log combined_vhost
ErrorLog $vsite->{basedir}/logs/error_log
ErrorDocument 401 /error/401-authorization.html
ErrorDocument 403 /error/403-forbidden.html
ErrorDocument 404 /error/404-file-not-found.html
ErrorDocument 500 /error/500-internal-server-error.html
RewriteEngine on
RewriteCond %{HTTP_HOST}                !^$vhost->{ipaddr}(:80)?\$
RewriteCond %{HTTP_HOST}                !^$vhost->{fqdn}(:80)?\$ [NC]
RewriteRule ^/(.*)                      http://$vhost->{fqdn}/\$1 [L,R]
# Cobalt administrative interface HTTPS redirection
RewriteEngine On
RewriteCond %{HTTP_HOST}                ^([^:]+)
RewriteRule ^/admin/?\$                  https://%1:444/login.php? [L,R]
RewriteCond %{HTTP_HOST}                ^([^:]+)
RewriteRule ^/cobalt/?\$                 https://%1:444/login.php? [L,R]
RewriteRule ^/personal/?\$               https://%1:444/login.php? [L,R]
RewriteCond %{HTTP_HOST}                ^([^:]+)

# redirection
RewriteRule ^/users/([^/]+)(.*)         /~\$1\$2 [L,R]

# user rewriting
RewriteCond %{HTTP_HOST}                ^([^:]+)
RewriteRule ^/~([^/]+)(.*)              -
RewriteCond /home/users/\$1              -d
RewriteRule ^/~([^/]+)(.*)              /home/users/\$1/web\$2 [L]
 
# Cobalt administrative interface HTTP redirection
RewriteCond %{HTTP_HOST}                ^([^:]+)
RewriteRule ^/login/?\$                  https://%1:444/login.php? [L,R]
RewriteOptions inherit
AliasMatch ^/~([^/]+)(/(.*))?           \$user_root

Include $include_file
</VirtualHost>
END

    if ($ssl->{enabled}) {
	if (-f "$vsite->{basedir}/certs/ca-certs")
	{
		$cafile = "SSLCACertificateFile	$vsite->{basedir}/certs/ca-certs";
	}
	if (-f "$vsite->{basedir}/certs/certificate" &&
	    -f "$vstie->{basedir}/certs/key") {
		$vhost_conf .=<<END;
<VirtualHost $vhost->{ipaddr}:443>
SSLengine on
$cafile
SSLCertificateFile 	$vsite->{basedir}/certs/certificate
SSLCertificateKeyFile	$vsite->{basedir}/certs/key
ServerName $vhost->{fqdn}
ServerAlias $vsite->{webAliases}
ServerAdmin $vhost->{serverAdmin}
DocumentRoot $vhost->{documentRoot}
ErrorDocument 401 /error/401-authorization.html
ErrorDocument 403 /error/403-forbidden.html
ErrorDocument 404 /error/404-file-not-found.html
ErrorDocument 500 /error/500-internal-server-error.html
</VirtualHost>
END
	} else {
		$cce->bye('FAIL', "Can't add SSL configuration to a site with no certificate!");
	}
    }

    # append line marking the end of the section specifically owned by the VirtualHost
    my $end_mark = "# end of VirtualHost owned section\n";
    $vhost_conf .= $end_mark;

    my $conf_printed = 0;

    while (<$in>)
    {
    	if (!$conf_printed && /^$end_mark$/)
    	{
    		print $out $vhost_conf;
    		$conf_printed = 1;
    	}
    	elsif ($conf_printed)
    	{
    		# print out information entered by other objects
    		print $out $_;
    	}
    }

    if (!$conf_printed)
    {
    	print $out $vhost_conf;
    }

    return 1;
}
# Copyright (c) 2003 Sun Microsystems, Inc. All  Rights Reserved.
# 
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions are met:
# 
# -Redistribution of source code must retain the above copyright notice, 
# this list of conditions and the following disclaimer.
# 
# -Redistribution in binary form must reproduce the above copyright notice, 
# this list of conditions and the following disclaimer in the documentation  
# and/or other materials provided with the distribution.
# 
# Neither the name of Sun Microsystems, Inc. or the names of contributors may 
# be used to endorse or promote products derived from this software without 
# specific prior written permission.
# 
# This software is provided "AS IS," without a warranty of any kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY EXCLUDED. SUN MICROSYSTEMS, INC. ("SUN") AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
# 
# You acknowledge that  this software is not designed or intended for use in the design, construction, operation or maintenance of any nuclear facility.
